/*------------------------------------------------
The next series of functions were originally saved
in the CMDBUILD.C file.  These functions build
a command string.
------------------------------------------------*/

#include <stdlib.h>
#include <ctype.h>
#include "tdp.h"

/*----------------------------------------------------------------------  
--------
------------------------------------------------------------------------  
------*/
xdata char cmdbuf [1 + MAX_CMD_LEN];	/* command buffer */
unsigned char cmdndx;				/* command index */

/*----------------------------------------------------------------------  
--------
Initialize the command buffer and index.
------------------------------------------------------------------------  
------*/
void cmdb_init (void)
{
cmdndx = 0;
cmdbuf [0] = '\0';
}

/*----------------------------------------------------------------------  
--------
Prompt for a command and display the current command buffer.  Note that the
com_puts was not included in my previous example since it is so trivial.
------------------------------------------------------------------------  
------*/
void cmdb_prompt (void)
{
com_puts ("COMMAND: ");
com_puts (cmdbuf);
}

/*----------------------------------------------------------------------  
--------
Build a command string.  This functions gets characters from the serial 
buffer
and appends them to the end of the command buffer.  If no character is 
available
the function returns NULL.  If a newline character is read, a pointer to 
the
buffer is returned.  Do NOT reinvoke this function before extracting the 
command
from the buffer.
------------------------------------------------------------------------  
------*/
const char *cmdb_scan (void)
{
int c;

/*------------------------------------------------
------------------------------------------------*/
while (1)
  {
  if ((c = com_getchar ()) == -1)	/* No character ? */
    break;					/* Exit NOW */

  if (c == '\r')				/* Newline? */
    {
    com_puts ("\r\n");			/* Output it and ... */
    return (cmdbuf);			/* Return the buffer address */
    }

  if ((c == '\b') && (cmdndx != 0))	/* Backspace? */
    {
    com_puts ("\b \b");
    cmdbuf [--cmdndx] = '\0';
    continue;
    }

  if (!isprint (c))			/* Printable character? */
    {
  BEEPCHAR:
    com_putchar ('\x7');
    continue;
    }

  if (cmdndx >= MAX_CMD_LEN)		/* Past buffer length? */
    goto BEEPCHAR;

  com_putchar (c);				/* Output char */
  cmdbuf [cmdndx++] = (unsigned char) c;	/* Add to the buffer */
  cmdbuf [cmdndx]   = '\0';			/* NULL-Terminate buffer */
  }

/*------------------------------------------------
------------------------------------------------*/
return (NULL);
}

